==> php82-nextcloud-29.0.8.tgz: share/nextcloud/apps/text/l10n/zh_CN.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "文件已上传",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上传文件超出了php.ini中upload_max_filesize的限制",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传文件超出了HTML表单中MAX_FILE_SIZE的限制",
    "The file was only partially uploaded" : "仅部分文件成功上传",
    "No file was uploaded" : "未有上传的文件",
    "Missing a temporary folder" : "缺失一个临时文件夹",
    "Could not write file to disk" : "无法向磁盘中写入文件",
    "A PHP extension stopped the file upload" : "一个PHP扩展插件终止了文件上传",
    "No file uploaded or file size exceeds maximum of %s" : "没有文件上传成功或者文件大小超出了最大%s的限制",
    "Nextcloud Text" : "Nextcloud 文本",
    "text document" : "文本文档",
    "New text file" : "新建文本文件",
    "Create new text file" : "创建新的记事本文件",
    "Editing session has expired. Please reload the page." : "编辑会话超时。请重载页面。",
    "{user} has mentioned you in the text document {node}" : "{user} 在记事本文件 {node} 中提到你",
    "This file cannot be displayed as download is disabled by the share" : "由于分享时下载已被禁用，该文件无法显示。",
    "File not found" : "文件未找到",
    "Readme" : "自述文件",
    "Text" : "文本 ",
    "📝 Collaborative document editing" : "文档协作编辑",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 协作式的文档编辑！**\n\n- **📝 专注的写作：** 无干扰，只有您需要的格式化。\n- **🙋 一起工作：** 与朋友和同事共享协作，无论他们是否使用Nextcloud！\n- **💾 开放标准：** 文件将保存为 [Markdown](https://en.wikipedia.org/wiki/Markdown)，所以您也可以使用任何其他文本应用。\n- **✊ 雄厚基础：** 我们使用 [🐈 tiptap](https://tiptap.scrumpy.io) ，它基于 [🦉 ProseMirror](https://prosemirror.net) – 非常感谢它们！",
    "Nextcloud Assistant" : "Nextcloud助手",
    "Translate" : "翻译",
    "Show assistant results" : "显示助手结果",
    "Insert result" : "插入结果",
    "Show result" : "显示结果",
    "Delete task" : "删除任务",
    "Nextcloud Assistant result copied" : "已复制 Nextcloud 助手结果",
    "Could not copy result to clipboard" : "无法复制结果至剪切板",
    "Use current version" : "使用当前版本",
    "Use the saved version" : "使用保存的版本",
    "Reload" : "重载",
    "Document has been changed outside of the editor. The changes cannot be applied" : "文档已在编辑器外被更改。无法应用更改。",
    "Document could not be loaded. Please check your internet connection." : "文档无法被加载。请检查你的网络连接。",
    "Reconnect" : "重新连接",
    "Document idle for {timeout} minutes, click to continue editing" : "文档已闲置 {timeout} 分钟，点击以继续编辑",
    "This file is opened read-only as it is currently locked by {user}." : "该文件以仅读模式打开，其正被用户 {user} 锁定。",
    "Close outline view" : "关闭大纲视图",
    "Outline" : "大纲",
    "Enter your name so other people can see who is editing" : "输入你的名称来让其他用户可以看到是谁在编辑。",
    "Edit guest name" : "编辑访客姓名",
    "Guest" : "访客",
    "Save guest name" : "保存访客姓名",
    "Insert an attachment" : "插入一个附件",
    "Preview options" : "预览选项",
    "Text only" : "仅文字",
    "Show link preview" : "显示链接预览",
    "Remove link" : "删除链接",
    "guest" : "访客",
    "Active people" : "活动用户",
    "Save document" : "保存文档",
    "Last saved" : "最后一个保存",
    "Offline" : "离线",
    "Offline, changes will be saved when online" : "离线，更改将会在上线后保存",
    "Saving …" : "保存中 …",
    "Saved" : "已保存",
    "Last saved {lastSave}" : "最近保存 {lastSave}",
    "The document has been changed outside of the editor. The changes cannot be applied." : "本文档在编辑器外被更改。无法应用更改。",
    "Unsaved changes" : "未保存的更改",
    "Connection failed." : "连接失败。",
    "Formatting and shortcuts" : "排版和捷径",
    "Speed up your writing with simple shortcuts." : "利用简单快捷键加速写作",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "只需输入 markdown 语法或从下面使用键盘快捷键。",
    "Just type the Markdown syntax from below." : "只需从下面输入 markdown 语法",
    "Style" : "样式",
    "Syntax" : "语法",
    "Keyboard shortcuts" : "键盘快捷键",
    "New paragraph" : "新的段落",
    "Enter" : "输入",
    "Hard line break" : "强制换行",
    "followed by" : "后接",
    "Backspace" : "退格",
    "Shift" : "Shift",
    "Bold" : "加粗",
    "Bold text" : "粗文本",
    "Ctrl" : "Ctrl",
    "Italic" : "斜体",
    "Italicized text" : "斜文本",
    "Strikethrough" : "删除线",
    "Mistaken text" : "错误文本",
    "Underline" : "下划线",
    "Underlined text" : "下划线",
    "Heading 1" : "标题 1",
    "Heading level 1" : "标题级 1",
    "Heading 6" : "标题 6",
    "Heading level 6" : "标题级 6",
    "Unordered list" : "无编号列表",
    "An item" : "一个项目",
    "Ordered list" : "编号列表",
    "First item" : "第一个项目",
    "Checklist" : "清单",
    "To-Do item" : "代办事项",
    "Blockquote" : "块引用",
    "Quoted text" : "引用文本",
    "Code block" : "代码块",
    "Some code" : "一些代码",
    "Link" : "链接",
    "Insert emoji" : "插入 emoji",
    "emoji" : "表情符号",
    "Mention someone" : "提及某人",
    "name" : "名称",
    "Smart picker" : "Smart Picker",
    "something" : "某些东西",
    "Action" : "操作",
    "Undo" : "撤销",
    "Redo" : "重做",
    "Toggle outline" : "切换大纲",
    "Alt" : "Alt",
    "Edit link" : "编辑链接",
    "Save changes" : "保存更改",
    "Cancel" : "取消",
    "URL" : "URL",
    "Cannot copy, please copy the link manually" : "无法复制，请手动复制链接",
    "Copy link to clipboard" : "复制链接到剪贴板",
    "Upload from computer" : "从电脑上传",
    "Insert from Files" : "从文件插入",
    "Formatting help" : "排版帮助",
    "Link to file or folder" : "链接至文件或文件夹",
    "Link to website" : "链接至网站",
    "Update link" : "更新链接",
    "Open the Smart Picker" : "打开智能选择器",
    "Select file or folder to link to" : "选择需要链接的文件或文件夹",
    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}, \"{selectedSubMenuItemName}\" 已选择",
    "_%n word_::_%n words_" : ["%n 字"],
    "_%n char_::_%n chars_" : ["%n 字符"],
    "Editor actions" : "编辑器操作",
    "Formatting menu bar" : "格式化菜单栏",
    "Remaining actions" : "重命名操作",
    "To translate individual parts of the text, select it before using the translate function." : "如果你需要翻译部分文字内容，请在使用翻译功能前选中该部分文字",
    "Translate from" : "翻译至",
    "Select language" : "请选择语言",
    "Text to translate from" : "需要翻译的文字",
    "to" : "到",
    "Translated text result" : "文字翻译结果",
    "Replace" : "替换",
    "Insert" : "插入",
    "Detect language" : "检测语言",
    "Translate from {language}" : "翻译自 {language}",
    "Translate to {language}" : "翻译至 {language}",
    "Translation failed" : "翻译失败",
    "No emoji found" : "找不到任何表情",
    "No command found" : "找不到任何命令",
    "No user found" : "找不到任何用户",
    "No suggestion found" : "找不到任何建议",
    "Edit" : "编辑",
    "Copy code block" : "复制代码块",
    "Copy code" : "复制代码",
    "Code block options" : "代码块设置",
    "Code block language" : "代码块语言",
    "e.g. php, javascript, json…" : "比如 php, javascript, json…",
    "Source code" : "源代码",
    "Diagram" : "图标",
    "Both" : "都是",
    "Mermaid documentation" : "Mermaid 文档",
    "Delete this attachment" : "删除该附件",
    "Delete this image" : "删除该图片",
    "Failed to load" : "加载失败",
    "Could not find image in attachments list." : "在附件列表内无法找到任何图片。",
    "Add row before" : "在之前新增行",
    "Add row after" : "在之后新增行",
    "Delete this row" : "删除该行",
    "Left align column" : "左对齐列",
    "Center align column" : "居中对其列",
    "Right align column" : "右对齐列",
    "Add column before" : "在之前新增列",
    "Add column after" : "在之后新增列",
    "Delete this column" : "删除该列",
    "Delete this table" : "删除该表格",
    "Show folder description" : "显示文件夹描述",
    "Hide outline" : "隐藏大纲",
    "Show outline" : "显示大纲",
    "Headings" : "标题",
    "Heading 2" : "标题 2",
    "Heading 3" : "标题 3",
    "Heading 4" : "标题 4",
    "Heading 5" : "标题 5",
    "Lists" : "列表",
    "To-Do list" : "代办事项",
    "Table" : "表格",
    "Details" : "详情",
    "Insert link" : "插入链接",
    "Insert attachment" : "插入附件",
    "Command" : "命令",
    "Control" : "控制",
    "Option" : "选项",
    "Formatting" : "格式",
    "Add folder description" : "添加文件夹描述",
    "\"{name}\" already exist!" : "\"{name}\" 已存在！",
    "Created \"{name}\"" : "创建 \"{name}\"",
    "Copied to the clipboard" : "已复制到剪切板",
    "Could not copy to the clipboard" : "无法复制到剪切板",
    "Front matter" : "前言",
    "Link to this section" : "链接至本节",
    "Show author colors" : "显示作者颜色",
    "Author colors are only shown until everyone has closed the document." : "直到所有人都关闭了文档，才会显示作者颜色。",
    "Callouts" : "标记",
    "Info" : "信息",
    "Success" : "成功",
    "Warning" : "警告",
    "Danger" : "重要",
    "Add notes, lists or links …" : "添加笔记、列表或链接...",
    "Add description" : "添加描述"
},
"nplurals=1; plural=0;");

==> php82-nextcloud-30.0.2.tgz: share/nextcloud/apps/text/l10n/zh_CN.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "文件已上传",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上传文件超出了php.ini中upload_max_filesize的限制",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传文件超出了HTML表单中MAX_FILE_SIZE的限制",
    "The file was only partially uploaded" : "仅部分文件成功上传",
    "No file was uploaded" : "未有上传的文件",
    "Missing a temporary folder" : "缺失一个临时文件夹",
    "Could not write file to disk" : "无法向磁盘中写入文件",
    "A PHP extension stopped the file upload" : "一个PHP扩展插件终止了文件上传",
    "No file uploaded or file size exceeds maximum of %s" : "没有文件上传成功或者文件大小超出了最大%s的限制",
    "Nextcloud Text" : "Nextcloud 文本",
    "text document" : "文本文档",
    "New text file" : "新建文本文件",
    "Create new text file" : "创建新的记事本文件",
    "Editing session has expired. Please reload the page." : "编辑会话超时。请重载页面。",
    "{user} has mentioned you in the text document {node}" : "{user} 在记事本文件 {node} 中提到你",
    "This file cannot be displayed as download is disabled by the share" : "由于分享时下载已被禁用，该文件无法显示。",
    "File not found" : "文件未找到",
    "Readme" : "自述文件",
    "Text" : "文本 ",
    "📝 Collaborative document editing" : "文档协作编辑",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 协作式的文档编辑！**\n\n- **📝 专注的写作：** 无干扰，只有您需要的格式化。\n- **🙋 一起工作：** 与朋友和同事共享协作，无论他们是否使用Nextcloud！\n- **💾 开放标准：** 文件将保存为 [Markdown](https://en.wikipedia.org/wiki/Markdown)，所以您也可以使用任何其他文本应用。\n- **✊ 雄厚基础：** 我们使用 [🐈 tiptap](https://tiptap.scrumpy.io) ，它基于 [🦉 ProseMirror](https://prosemirror.net) – 非常感谢它们！",
    "Nextcloud Assistant" : "Nextcloud助手",
    "Translate" : "翻译",
    "Show assistant results" : "显示助手结果",
    "Insert result" : "插入结果",
    "Show result" : "显示结果",
    "Delete task" : "删除任务",
    "Nextcloud Assistant result copied" : "已复制 Nextcloud 助手结果",
    "Could not copy result to clipboard" : "无法复制结果至剪切板",
    "Use current version" : "使用当前版本",
    "Use the saved version" : "使用保存的版本",
    "Reload" : "重载",
    "Document has been changed outside of the editor. The changes cannot be applied" : "文档已在编辑器外被更改。无法应用更改。",
    "Document could not be loaded. Please check your internet connection." : "文档无法被加载。请检查你的网络连接。",
    "Reconnect" : "重新连接",
    "Document idle for {timeout} minutes, click to continue editing" : "文档已闲置 {timeout} 分钟，点击以继续编辑",
    "This file is opened read-only as it is currently locked by {user}." : "该文件以仅读模式打开，其正被用户 {user} 锁定。",
    "Close outline view" : "关闭大纲视图",
    "Outline" : "大纲",
    "Enter your name so other people can see who is editing" : "输入你的名称来让其他用户可以看到是谁在编辑。",
    "Edit guest name" : "编辑访客姓名",
    "Guest" : "访客",
    "Save guest name" : "保存访客姓名",
    "Insert an attachment" : "插入一个附件",
    "Preview options" : "预览选项",
    "Text only" : "仅文字",
    "Show link preview" : "显示链接预览",
    "Remove link" : "删除链接",
    "guest" : "访客",
    "Active people" : "活动用户",
    "Save document" : "保存文档",
    "Last saved" : "最近保存",
    "Offline" : "离线",
    "Offline, changes will be saved when online" : "离线，更改将会在上线后保存",
    "Saving …" : "保存中 …",
    "Saved" : "已保存",
    "Last saved {lastSave}" : "最近保存 {lastSave}",
    "The document has been changed outside of the editor. The changes cannot be applied." : "本文档在编辑器外被更改。无法应用更改。",
    "Unsaved changes" : "未保存的更改",
    "Connection failed." : "连接失败。",
    "Formatting and shortcuts" : "排版和捷径",
    "Speed up your writing with simple shortcuts." : "利用简单快捷键加速写作",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "只需输入 markdown 语法或从下面使用键盘快捷键。",
    "Just type the Markdown syntax from below." : "只需从下面输入 markdown 语法",
    "Style" : "样式",
    "Syntax" : "语法",
    "Keyboard shortcuts" : "键盘快捷键",
    "New paragraph" : "新的段落",
    "Enter" : "输入",
    "Hard line break" : "强制换行",
    "followed by" : "后接",
    "Backspace" : "退格",
    "Shift" : "Shift",
    "Bold" : "加粗",
    "Bold text" : "粗文本",
    "Ctrl" : "Ctrl",
    "Italic" : "斜体",
    "Italicized text" : "斜文本",
    "Strikethrough" : "删除线",
    "Mistaken text" : "错误文本",
    "Underline" : "下划线",
    "Underlined text" : "下划线",
    "Heading 1" : "标题 1",
    "Heading level 1" : "标题级 1",
    "Heading 6" : "标题 6",
    "Heading level 6" : "标题级 6",
    "Unordered list" : "无编号列表",
    "An item" : "一个项目",
    "Ordered list" : "编号列表",
    "First item" : "第一个项目",
    "Checklist" : "清单",
    "To-Do item" : "代办事项",
    "Blockquote" : "块引用",
    "Quoted text" : "引用文本",
    "Code block" : "代码块",
    "Some code" : "一些代码",
    "Link" : "链接",
    "Insert emoji" : "插入 emoji",
    "emoji" : "表情符号",
    "Mention someone" : "提及某人",
    "name" : "名称",
    "Smart picker" : "Smart Picker",
    "something" : "某些东西",
    "Action" : "操作",
    "Undo" : "撤销",
    "Redo" : "重做",
    "Toggle outline" : "切换大纲",
    "Alt" : "Alt",
    "Edit link" : "编辑链接",
    "Save changes" : "保存更改",
    "Cancel" : "取消",
    "URL" : "URL",
    "Cannot copy, please copy the link manually" : "无法复制，请手动复制链接",
    "Copy link to clipboard" : "复制链接到剪贴板",
    "Upload from computer" : "从电脑上传",
    "Insert from Files" : "从文件插入",
    "Formatting help" : "排版帮助",
    "Link to file or folder" : "链接至文件或文件夹",
    "Link to website" : "链接至网站",
    "Update link" : "更新链接",
    "Open the Smart Picker" : "打开智能选择器",
    "Select file or folder to link to" : "选择需要链接的文件或文件夹",
    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}, \"{selectedSubMenuItemName}\" 已选择",
    "_%n word_::_%n words_" : ["%n 字"],
    "_%n char_::_%n chars_" : ["%n 字符"],
    "Editor actions" : "编辑器操作",
    "Formatting menu bar" : "格式化菜单栏",
    "Remaining actions" : "重命名操作",
    "To translate individual parts of the text, select it before using the translate function." : "如果你需要翻译部分文字内容，请在使用翻译功能前选中该部分文字",
    "Translate from" : "翻译至",
    "Select language" : "请选择语言",
    "Text to translate from" : "需要翻译的文字",
    "to" : "到",
    "Translate to" : "翻译至",
    "Translated text result" : "文字翻译结果",
    "Replace" : "替换",
    "Insert" : "插入",
    "Detect language" : "检测语言",
    "Translate from {language}" : "翻译自 {language}",
    "Translate to {language}" : "翻译至 {language}",
    "Translation failed" : "翻译失败",
    "No emoji found" : "找不到任何表情",
    "No command found" : "找不到任何命令",
    "No user found" : "找不到任何用户",
    "No suggestion found" : "找不到任何建议",
    "Edit" : "编辑",
    "Copy code block" : "复制代码块",
    "Copy code" : "复制代码",
    "Code block options" : "代码块设置",
    "Code block language" : "代码块语言",
    "e.g. php, javascript, json…" : "比如 php, javascript, json…",
    "Source code" : "源代码",
    "Diagram" : "图标",
    "Both" : "都是",
    "Mermaid documentation" : "Mermaid 文档",
    "Delete this attachment" : "删除该附件",
    "Delete this image" : "删除该图片",
    "Failed to load" : "加载失败",
    "Could not find image in attachments list." : "在附件列表内无法找到任何图片。",
    "Add row before" : "在之前新增行",
    "Add row after" : "在之后新增行",
    "Delete this row" : "删除该行",
    "Left align column" : "左对齐列",
    "Center align column" : "居中对其列",
    "Right align column" : "右对齐列",
    "Add column before" : "在之前新增列",
    "Add column after" : "在之后新增列",
    "Delete this column" : "删除该列",
    "Delete this table" : "删除该表格",
    "Show folder description" : "显示文件夹描述",
    "Hide outline" : "隐藏大纲",
    "Show outline" : "显示大纲",
    "Headings" : "标题",
    "Heading 2" : "标题 2",
    "Heading 3" : "标题 3",
    "Heading 4" : "标题 4",
    "Heading 5" : "标题 5",
    "Lists" : "列表",
    "To-Do list" : "代办事项",
    "Table" : "表格",
    "Details" : "详情",
    "Insert link" : "插入链接",
    "Insert attachment" : "插入附件",
    "Command" : "命令",
    "Control" : "控制",
    "Option" : "选项",
    "Formatting" : "格式",
    "Start writing, or try '/' to add, '@' to mention…" : "开始写作，或尝试用 “/” 添加，用 “@” 提及…",
    "Add folder description" : "添加文件夹描述",
    "\"{name}\" already exist!" : "\"{name}\" 已存在！",
    "Created \"{name}\"" : "创建 \"{name}\"",
    "Copied to the clipboard" : "已复制到剪切板",
    "Could not copy to the clipboard" : "无法复制到剪切板",
    "Front matter" : "前言",
    "Link to this section" : "链接至本节",
    "Show author colors" : "显示作者颜色",
    "Author colors are only shown until everyone has closed the document." : "直到所有人都关闭了文档，才会显示作者颜色。",
    "Callouts" : "标记",
    "Info" : "信息",
    "Success" : "成功",
    "Warning" : "警告",
    "Danger" : "重要",
    "Add notes, lists or links …" : "添加笔记、列表或链接...",
    "Add description" : "添加描述"
},
"nplurals=1; plural=0;");
